@@ -526,7 +526,7 @@ def backprojection_clustering ( analyte_df , bRanked=False , n_dimensions=2 ,
     if bDoFeatures :
         #
         dM1 = absolute_coordinates_to_distance_matrix( rana_df.values   )
-        pd.DataFrame(dM1,index=rana_df.index,columns=rana_df.index).to_csv('../data/dM1.tsv','\t')
+        #pd.DataFrame(dM1,index=rana_df.index,columns=rana_df.index).to_csv('../data/dM1.tsv','\t')
         #
         # Project it back onto first two components
         max_var_projection = distance_matrix_to_absolute_coordinates ( dM1 , n_dimensions=n_dimensions )
@@ -538,17 +538,62 @@ def backprojection_clustering ( analyte_df , bRanked=False , n_dimensions=2 ,
         #
         # And again for all the samples
         dM2 = absolute_coordinates_to_distance_matrix( rana_df.T.values )
-        pd.DataFrame(dM2,index=rana_df.columns,columns=rana_df.columns).to_csv('../data/dM2.tsv','\t')
+        #pd.DataFrame(dM2,index=rana_df.columns,columns=rana_df.columns).to_csv('../data/dM2.tsv','\t')
         #
         # This algorithm is exact but scales somewhere between n^2 and n log n
         max_var_projection = distance_matrix_to_absolute_coordinates ( dM2 , n_dimensions=n_dimensions )
         cluster_coords_s = pd.DataFrame( max_var_projection ,
                                     columns = rana_df.columns ,
                                     index = dimcrdnames ).T
-        cluster_coords_s.to_csv('../data/conclust_s.tsv','\t')
+        #cluster_coords_s.to_csv('../data/conclust_s.tsv','\t')
 
     return ( cluster_coords_f,cluster_coords_s )
 
+def dbscan ( data_frame = None , distance_matrix = None ,
+        eps = None, minPts = None , bVerbose = False ) :
+    if bVerbose :
+        print ( "THIS IMPLEMENTATION FOR DBSCAN" )
+        print ( "ASSESSMENT OF NOISE DIFFERS FROM" )
+        print ( "THE IMPLEMENTATION FOUND IN SKLEARN")
+    #
+    # FOR A DESCRIPTION OF THE CONNECTIVITY READ PAGE 30 (16 INTERNAL NUMBERING) of:
+    # https://kth.diva-portal.org/smash/get/diva2:748464/FULLTEXT01.pdf
+    #from impetuous.clustering import absolute_coordinates_to_distance_matrix
+    #from impetuous.clustering import connectivity
+    import operator
+    if not operator.xor( data_frame is None , distance_matrix is None ) :
+        print ( "ONLY SUPPLY A SINGE DATA FRAME OR A DISTANCE MATRIX" )
+        print ( "dbscan FAILED" )
+        print ( "DATA MATRICES NEEDS TO BE SPECIFIED WITH \" distance_matrix = ... \" " )
+        exit(1)
+    if not data_frame is None :
+        if not 'pandas' in str(type(data_frame)) :
+            print ( "ONLY SUPPLY A SINGE DATA FRAME WITH ABSOLUTE COORDINATES" )
+            print ( "DATA MATRICES NEEDS TO BE SPECIFIED WITH \" data_frame = ... \" " )
+            print ( "dbscan FAILED" )
+            exit ( 1 )
+        if bVerbose :
+            print ( data_frame )
+        distance_matrix = absolute_coordinates_to_distance_matrix(data_frame.values)
+    if not ( 'float' in str(type(eps)).lower() and 'int' in str(type(minPts)).lower() ) :
+        print ( "TO CALL THE dbscan PLEASE SPECIFY AT LEAST A DATA FRAME OR")
+        print ( "ITS CORRESPONDING DISTANCE MATRIX AS WELL AS THE DISTANCE CUTOFF PARAMETER" )
+        print ( "AND THE MINIMAL AMOUNT OF NEIGHBOUR POINTS TO CONSIDER IT CLUSTERED")
+        print ( "dbscan ( data_frame = None , distance_matrix = None , eps = None, minPts = None )" )
+    if 'panda' in str(type(distance_matrix)).lower() :
+        distance_matrix = distance_matrix.values
+    distance_matrix_ = distance_matrix.copy()
+    isNoise = np.sum(distance_matrix_<eps,0)-1 < minPts
+    i_ = 0
+    for ib in isNoise :
+        if ib :
+            distance_matrix_ [ i_] = ( 1+eps )*10.0
+            distance_matrix_.T[i_] = ( 1+eps )*10.0
+            distance_matrix_[i_][i_] = 0.
+        i_ = i_+1
+    clustercontent , clustercontacts  =  connectivity(distance_matrix_,eps)
+    return ( {'cluster content': clustercontent, 'clusterid-particleid' : clustercontacts, 'is noise':isNoise} )
+
 
 if __name__ == '__main__' :
 
@@ -557,7 +602,7 @@ if __name__ == '__main__' :
         # TEST DEPENDS ON THE DIABETES DATA FROM BROAD INSTITUTE
         filename = './Diabetes_collapsed_symbols.gct'
         df_ = pd.read_csv(filename,'\t',index_col=0,header=2)
-        ddf = df_.loc[:,[ col for col in df_.columns if '_' in col ]] 
+        ddf = df_.loc[:,[ col for col in df_.columns if '_' in col ]]
         ddf .index = [idx.split('/')[0] for idx in ddf.index]
         run_clustering_and_write_gmt( ddf , clustering_algorithm )
         #
@@ -565,12 +610,12 @@ if __name__ == '__main__' :
         CLU .approximate_density_clustering(ddf)
         CLU .write_gmt()
 
-    if False :
+    if True :
         A = np.array( [ [0.00, 0.10, 0.10, 9.00, 9.00, 9.00],
         		[0.10, 0.00, 0.15, 9.00, 9.00, 9.00],
         		[0.10, 0.15, 0.00, 9.00, 9.00, 9.00],
         		[9.00, 9.00, 9.00, 0.00, 0.10, 0.10],
         		[9.10, 9.00, 9.00, 0.10, 0.00, 0.15],
         		[9.10, 9.00, 9.00, 0.10, 0.15, 0.00] ] )
-        print( connectivity(A,0.01) )
-
+        print ( connectivity(A,0.11) )
+        print ( dbscan(distance_matrix=pd.DataFrame(A).values,eps=0.11,minPts=2) )
